/*	License
 * 		inside EU: EUPL
 * 		outside EU: GPL or EUPL
 *  The program comes AS IS and without any warranty unless required by law
 *  (C) 2012 thecodemonkey
 */

package gui.layout;

public class AnchorLayoutConstraints {
	private int left,right,top,bottom;
	private int width,height;
	private boolean distrV,distrH;
	private boolean percentV,percentH;
	
	public static AnchorLayoutConstraints get(AnchorParam... pos){
		AnchorLayoutConstraints c=new AnchorLayoutConstraints();
		
		for (AnchorParam p:pos) {
			switch (p.getPos()) {
			case left:
				c.setLeft(p.getVal());
				break;
			case right:
				c.setRight(p.getVal());
				break;
			case top:
				c.setTop(p.getVal());
				break;
			case bottom:
				c.setBottom(p.getVal());
				break;
			case width:
				c.setWidth(p.getVal());
				break;
			case height:
				c.setHeight(p.getVal());
				break;
			case distributeH:
				c.setDistrH(true);
				break;
			case distributeV:
				c.setDistrV(true);
				break;
			case percentH:
				c.setPercentH(true);
				c.setLeft(p.getVal());
				break;
			case percentV:
				c.setPercentV(true);
				c.setTop(p.getVal());
				break;
			}
		}
		
		return c;
	}
	
	
	public AnchorLayoutConstraints() {
		left=-1;
		right=-1;
		top=-1;
		bottom=-1;
	}
	
	public void setBottom(int bottom) {
		this.bottom = bottom;
	}
	
	public void setLeft(int left) {
		this.left = left;
	}
	
	public void setRight(int right) {
		this.right = right;
	}
	
	public void setHeight(int height) {
		this.height = height;
	}
	
	public void setTop(int top) {
		this.top = top;
	}
	
	public void setDistrH(boolean distrH) {
		this.distrH = distrH;
	}
	
	public void setDistrV(boolean distrV) {
		this.distrV = distrV;
	}
	
	public void setPercentH(boolean percentH) {
		this.percentH = percentH;
	}
	
	public void setPercentV(boolean percentV) {
		this.percentV = percentV;
	}
	
	public int getBottom() {
		return bottom;
	}
	
	public int getLeft() {
		return left;
	}
	
	public int getHeight() {
		return height;
	}
	
	public int getRight() {
		return right;
	}
	
	public int getTop() {
		return top;
	}
	
	public int getWidth() {
		return width;
	}
	
	public void setWidth(int width) {
		this.width = width;
	}
	
	public boolean left() {
		return left>-1;
	}
	
	public boolean right() {
		return right>-1;
	}
	
	public boolean top() {
		return top>-1;
	}
	
	public boolean bottom() {
		return bottom>-1;
	}

	public boolean distrH() {
		return distrH;
	}
	
	public boolean distrV() {
		return distrV;
	}
	
	public boolean isPercentH() {
		return percentH;
	}
	
	public boolean isPercentV() {
		return percentV;
	}
	
	/**
	 * centered, fixed size 
	 */
	public static AnchorLayoutConstraints getBySize(int width, int height) {
		AnchorLayoutConstraints c=new AnchorLayoutConstraints();
		c.setWidth(width);
		c.setHeight(height);
		return c;
	}
	
	public static AnchorLayoutConstraints getByBorder(int left,int right,int top,int bottom) {
		AnchorLayoutConstraints c=new AnchorLayoutConstraints();
		c.setLeft(left);
		c.setRight(right);
		c.setTop(top);
		c.setBottom(bottom);
		return c;
	}
	
	
}
